pub fn xml_response(xml: String, request_id: &str) -> Response<StsResponseBody>Expand description
Build a success XML response with the given body and request ID.
pub fn xml_response(xml: String, request_id: &str) -> Response<StsResponseBody>Build a success XML response with the given body and request ID.